pub enum TransactionUnsigned {
Transaction7702Unsigned(Transaction7702Unsigned),
Transaction4844Unsigned(Transaction4844Unsigned),
Transaction1559Unsigned(Transaction1559Unsigned),
Transaction2930Unsigned(Transaction2930Unsigned),
TransactionLegacyUnsigned(TransactionLegacyUnsigned),
}Variants
Transaction7702Unsigned(Transaction7702Unsigned)
Transaction4844Unsigned(Transaction4844Unsigned)
Transaction1559Unsigned(Transaction1559Unsigned)
Transaction2930Unsigned(Transaction2930Unsigned)
TransactionLegacyUnsigned(TransactionLegacyUnsigned)
Implementations
Sourceimpl TransactionUnsigned
impl TransactionUnsigned
Sourcepub fn unsigned_payload(&self) -> Vec<u8> ⓘ
pub fn unsigned_payload(&self) -> Vec<u8> ⓘ
Return the bytes to be signed by the private key.
Sourceimpl TransactionUnsigned
impl TransactionUnsigned
Sourcepub fn dummy_signed_payload(self) -> Vec<u8> ⓘ
pub fn dummy_signed_payload(self) -> Vec<u8> ⓘ
Get a signed transaction payload with a dummy 65 bytes signature.
Sourceimpl TransactionUnsigned
impl TransactionUnsigned
Sourcepub fn from_signed(tx: TransactionSigned) -> Self
pub fn from_signed(tx: TransactionSigned) -> Self
Extract the unsigned transaction from a signed transaction.
Sourcepub fn with_signature(self, signature: [u8; 65]) -> TransactionSigned
pub fn with_signature(self, signature: [u8; 65]) -> TransactionSigned
Create a signed transaction from an TransactionUnsigned and a signature.